package com.virtual.plat.server.virtualhost;

import com.virtual.common.FuncUtil;
import com.virtual.plat.server.entity.Domain;
import com.virtual.plat.server.entity.QueryConfig;
import com.virtual.plat.server.entity.QueryResult;
import com.virtual.plat.server.entity.QueryConfig.SortDir;
import com.virtual.plat.server.virtualhost.DomainDao;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.apache.commons.collections.CollectionUtils;
import org.hibernate.Criteria;
import org.hibernate.FetchMode;
import org.hibernate.SQLQuery;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Projection;
import org.hibernate.criterion.Projections;
import org.hibernate.criterion.Restrictions;
import org.hibernate.type.StandardBasicTypes;
import org.springframework.stereotype.Repository;

@Repository("domainDao")
public class DomainDaoImpl implements DomainDao {

   @Resource
   private SessionFactory sessionFactory = null;


   public QueryResult readByCondition(QueryConfig var1) {
      if(var1 == null) {
         var1 = new QueryConfig();
      }

      QueryResult var2 = new QueryResult();
      Criteria var3 = this.sessionFactory.getCurrentSession().createCriteria(Domain.class);
      if(var1.getRestriction("id") != null) {
         var3.add(Restrictions.eq("id", var1.getRestriction("id")));
      }

      List var4;
      if(var1.getRestriction("idList") != null) {
         var4 = (List)var1.getRestriction("idList");
         var3.add(Restrictions.in("id", var4));
      }

      if(var1.getRestriction("domainName") != null) {
         var3.add(Restrictions.like("domainName", var1.getRestriction("domainName").toString().trim()));
      }

      if(var1.getRestriction("title") != null) {
         var3.add(Restrictions.like("title", var1.getRestriction("title").toString().trim()));
      }

      if(var1.getRestriction("hostId") != null) {
         var3.add(Restrictions.eq("hostId", var1.getRestriction("hostId")));
      }

      if(var1.getRestriction("hostPoolId") != null) {
         var3.add(Restrictions.eq("hostPoolId", var1.getRestriction("hostPoolId")));
      }

      if(var1.getRestriction("clusterId") != null) {
         var3.add(Restrictions.eq("clusterId", var1.getRestriction("clusterId")));
      }

      if(var1.getRestriction("enable") != null) {
         var3.add(Restrictions.eq("enable", var1.getRestriction("enable")));
      } else {
         var3.add(Restrictions.le("enable", Integer.valueOf(1)));
      }

      if(var1.getRestriction("cloudId") != null) {
         var3.add(Restrictions.eq("publicCloudId", var1.getRestriction("cloudId")));
      }

      if(var1.getRestriction("cloudIds") != null) {
         var4 = (List)var1.getRestriction("cloudIds");
         var3.add(Restrictions.in("publicCloudId", var4));
      }

      if(var1.getRestriction("operatorGroupCode") != null) {
         var3.add(Restrictions.like("operatorGroupCode", var1.getRestriction("operatorGroupCode")));
      }

      if(var1.getRestriction("vmIdList") != null) {
         var4 = (List)var1.getRestriction("vmIdList");
         var3.add(Restrictions.in("foreignId", var4));
      }

      if(var1.getRestriction("uniqueKey") != null) {
         var3.add(Restrictions.eq("uniqueKey", var1.getRestriction("uniqueKey")));
      }

      if(var1.getRestriction("uniqueKeyList") != null) {
         var4 = (List)var1.getRestriction("uniqueKeyList");
         var3.add(Restrictions.in("uniqueKey", var4));
      }

      if(var1.getRestriction("exclusiveUniqueKeyList") != null && (var4 = (List)var1.getRestriction("exclusiveUniqueKeyList")).size() != 0) {
         var3.add(Restrictions.not(Restrictions.in("uniqueKey", var4)));
      }

      if(var1.getRestriction("status") != null) {
         var3.add(Restrictions.eq("status", var1.getRestriction("status")));
      }

      if(var1.isPaging()) {
         long var6 = FuncUtil.getLongValue(var3.setProjection(Projections.rowCount()).uniqueResult()).longValue();
         var2.setOffset((long)var1.getOffset());
         var2.setTotalLength(var6);
         if(var6 == 0L) {
            var2.setData(new ArrayList());
            return var2;
         }

         var3.setProjection((Projection)null);
         if(var1.getRestriction("loadStore") != null) {
            var3.setFetchMode("storages", FetchMode.JOIN);
            var3.setResultTransformer(Criteria.DISTINCT_ROOT_ENTITY);
         } else {
            var3.setResultTransformer(Criteria.ROOT_ENTITY);
         }

         var3.setFirstResult(var1.getOffset());
         var3.setMaxResults(var1.getLimit());
      }

      if(var1.isSort()) {
         if(var1.getSortDir() == SortDir.Asc) {
            var3.addOrder(Order.asc(var1.getSortField()));
         } else {
            var3.addOrder(Order.desc(var1.getSortField()));
         }
      }

      var2.setData(var3.list());
      return var2;
   }

   public void insert(Domain var1) {
      if(var1.getDomainName() != null) {
         var1.setDomainName(var1.getDomainName().trim());
      }

      if(var1.getTitle() == null) {
         var1.setTitle(var1.getDomainName());
      }

      this.sessionFactory.getCurrentSession().save(var1);
   }

   public void updateBySql(String var1) {
      if(var1 != null) {
         this.sessionFactory.getCurrentSession().createSQLQuery(var1).executeUpdate();
      }
   }

   public void updateDomainStatus(Long var1, Long var2, String var3) {
      StringBuilder var4;
      (var4 = new StringBuilder()).append("UPDATE TBL_DOMAIN SET STATUS = \'" + var3 + "\'");
      var4.append(" WHERE PUBLIC_CLOUD_ID = " + var2);
      var4.append(" AND ID = " + var1);
      this.sessionFactory.getCurrentSession().createSQLQuery(var4.toString()).executeUpdate();
   }

   public void deleteDomainByCloudId(Long var1) {
      StringBuilder var2;
      (var2 = new StringBuilder()).append("DELETE FROM TBL_DOMAIN");
      if(var1 != null) {
         var2.append(String.format(" WHERE PUBLIC_CLOUD_ID = %d", new Object[]{var1}));
      }

      this.sessionFactory.getCurrentSession().createSQLQuery(var2.toString()).executeUpdate();
   }

   public void updateUserVm(Long var1) {
      StringBuilder var2;
      (var2 = new StringBuilder()).append("UPDATE TBL_USER_VM SET TBL_USER_VM.TITLE = ( SELECT domain.TITLE FROM TBL_DOMAIN domain");
      var2.append(" WHERE TBL_USER_VM.UNIQUE_KEY = domain.UNIQUE_KEY AND TBL_USER_VM.PUBLIC_CLOUD_ID = domain.PUBLIC_CLOUD_ID)");
      var2.append(" WHERE ");
      if(var1 != null) {
         var2.append(" TBL_USER_VM.PUBLIC_CLOUD_ID=").append(var1).append(" AND ");
      }

      var2.append(" EXISTS ( SELECT domain.UNIQUE_KEY FROM TBL_DOMAIN domain WHERE TBL_USER_VM.UNIQUE_KEY = domain.UNIQUE_KEY AND TBL_USER_VM.PUBLIC_CLOUD_ID = domain.PUBLIC_CLOUD_ID)");
      this.sessionFactory.getCurrentSession().createSQLQuery(var2.toString()).executeUpdate();
   }

   public void update(String var1, String var2) {
      StringBuilder var3;
      (var3 = new StringBuilder()).append("UPDATE TBL_DOMAIN SET STATUS = \'" + var2 + "\'");
      var3.append(" WHERE UUID = \'" + var1 + "\'");
      this.sessionFactory.getCurrentSession().createSQLQuery(var3.toString()).executeUpdate();
   }

   public void updateDomainStatus(String var1, Long var2, String var3) {
      StringBuilder var4;
      (var4 = new StringBuilder()).append("UPDATE TBL_DOMAIN SET STATUS = \'" + var3 + "\'");
      var4.append(" WHERE PUBLIC_CLOUD_ID = " + var2);
      var4.append(" AND UNIQUE_KEY = \'" + var1);
      var4.append("\'");
      this.sessionFactory.getCurrentSession().createSQLQuery(var4.toString()).executeUpdate();
   }

   public void deleteDomain(String var1) {
      StringBuilder var2;
      (var2 = new StringBuilder()).append("DELETE FROM TBL_DOMAIN");
      var2.append(" WHERE UUID = \'" + var1 + "\'");
      this.sessionFactory.getCurrentSession().createSQLQuery(var2.toString()).executeUpdate();
   }

   public void updateDomainStatus(String var1, long var2) {
      StringBuilder var4;
      (var4 = new StringBuilder()).append("UPDATE TBL_DOMAIN SET STATUS = \'" + var1 + "\'");
      var4.append(" WHERE ID = \'" + var2 + "\'");
      this.sessionFactory.getCurrentSession().createSQLQuery(var4.toString()).executeUpdate();
   }

   public Domain readById(Long var1) {
      Session var2;
      Domain var3;
      if((var3 = (Domain)(var2 = this.sessionFactory.getCurrentSession()).createCriteria(Domain.class).add(Restrictions.eq("id", var1)).uniqueResult()) != null) {
         var2.evict(var3);
      }

      return var3;
   }

   public Domain readByUniqueKeyAndCloudId(String var1, long var2) {
      Criteria var4;
      (var4 = this.sessionFactory.getCurrentSession().createCriteria(Domain.class)).add(Restrictions.eq("uniqueKey", var1));
      var4.add(Restrictions.eq("publicCloudId", Long.valueOf(var2)));
      List var5;
      return CollectionUtils.isEmpty(var5 = var4.list())?null:(Domain)var5.get(0);
   }

   public List queryDomainPublicIdList() {
      ArrayList var1 = new ArrayList();
      Session var2 = this.sessionFactory.getCurrentSession();
      StringBuilder var3 = new StringBuilder("SELECT DISTINCT(PUBLIC_CLOUD_ID) FROM TBL_DOMAIN");
      Iterator var4 = var2.createSQLQuery(var3.toString()).list().iterator();

      while(var4.hasNext()) {
         Object var5 = var4.next();
         var1.add(Long.valueOf(((BigInteger)var5).longValue()));
      }

      return var1;
   }

   public void delDomainsByUniquekeys(long var1, List var3) {
      if(!var3.isEmpty()) {
         StringBuffer var4 = new StringBuffer();
         Iterator var7 = var3.iterator();

         while(var7.hasNext()) {
            String var5 = (String)var7.next();
            var4.append("\'").append(var5).append("\',");
         }

         String var8 = (var8 = var4.toString()).substring(0, var8.length() - 1);
         StringBuilder var6;
         (var6 = new StringBuilder()).append("DELETE FROM TBL_DOMAIN WHERE UNIQUE_KEY IN (");
         var6.append(var8).append(") AND PUBLIC_CLOUD_ID = ").append(var1);
         System.out.println(var6.toString());
         this.sessionFactory.getCurrentSession().createSQLQuery(var6.toString()).executeUpdate();
      }
   }

   public QueryResult readDomainsAndTempletsByCloudId(long var1) {
      QueryResult var3 = new QueryResult();
      Criteria var4;
      (var4 = this.sessionFactory.getCurrentSession().createCriteria(Domain.class)).add(Restrictions.eq("publicCloudId", Long.valueOf(var1)));
      var3.setData(var4.list());
      return var3;
   }

   public QueryResult readTemplatesByCloudId(long var1) {
      QueryResult var3 = new QueryResult();
      Criteria var4;
      (var4 = this.sessionFactory.getCurrentSession().createCriteria(Domain.class)).add(Restrictions.eq("publicCloudId", Long.valueOf(var1)));
      var4.add(Restrictions.eq("enable", Integer.valueOf(2)));
      var3.setData(var4.list());
      return var3;
   }

   public boolean update(Domain var1) {
      if(var1 == null) {
         return false;
      } else {
         this.sessionFactory.getCurrentSession().merge(var1);
         return true;
      }
   }

   public boolean delete(Domain var1) {
      if(var1 == null) {
         return false;
      } else {
         this.sessionFactory.getCurrentSession().delete(var1);
         return true;
      }
   }

   public QueryResult readTemplateByConfig(QueryConfig var1) {
      QueryResult var4 = new QueryResult();
      StringBuffer var2;
      (var2 = new StringBuffer("SELECT DISTINCT A.ID, C.ORG_ID FROM TBL_DOMAIN A ")).append(" INNER JOIN TBL_RESOURCE_POOL B ON A.PUBLIC_CLOUD_ID = B.CLOUD_ID ");
      var2.append(" INNER JOIN TBL_ORG_RESOURCE_POOL C ON B.ID = C.RESOURCE_POOL_ID ");
      var2.append(" WHERE A.ENABLE = 2");
      SQLQuery var5;
      if((var5 = this.sessionFactory.getCurrentSession().createSQLQuery(var2.toString())).list() != null && var5.list().size() != 0) {
         var4.setData(var5.list());
      }

      return var4;
   }

   public List readVmIdAndHostNameMapByUniqueKeyList(List var1) {
      StringBuilder var2 = new StringBuilder();
      Iterator var4 = var1.iterator();

      while(var4.hasNext()) {
         String var3 = (String)var4.next();
         var2.append("\'").append(var3).append("\',");
      }

      if(var2.length() > 0) {
         var2.deleteCharAt(var2.length() - 1);
      }

      StringBuilder var5;
      (var5 = new StringBuilder()).append("SELECT domain.ID, h.NAME FROM TBL_DOMAIN domain, TBL_HOST h WHERE domain.HOST_ID = h.ID AND domain.UNIQUE_KEY IN (").append(var2.toString()).append(")");
      SQLQuery var6;
      (var6 = this.sessionFactory.getCurrentSession().createSQLQuery(var5.toString())).addScalar("domain.ID", StandardBasicTypes.LONG);
      var6.addScalar("h.NAME", StandardBasicTypes.STRING);
      return var6.list();
   }
}
